@@ -26,14 +26,15 @@
 
 
 int
-main (int argc, char *argv[])
+main (int   argc,
+      char *argv[])
 {
-    bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-    textdomain (GETTEXT_PACKAGE);
-    setlocale (LC_ALL, "");
+  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
+  setlocale (LC_ALL, "");
 
-    Glib::RefPtr<GsmApplication> application = GsmApplication::get();
-    return application->run (argc, argv);
+  Glib::RefPtr<GsmApplication> application = GsmApplication::get ();
+
+  return application->run (argc, argv);
 }
-
