@@ -21,13 +21,15 @@
 
 #include "application.h"
 
-void            renice (GsmApplication *app, int nice);
-void            kill_process (GsmApplication *app, int sig);
+void renice (GsmApplication *app,
+             int             nice);
+void kill_process (GsmApplication *app,
+                   int             sig);
 
 struct ProcActionArgs
 {
-    GsmApplication *app;
-    int arg_value;
+  GsmApplication *app;
+  int arg_value;
 };
 
 #endif /* _GSM_PROCACTIONS_H_ */
